CLOgmaNeo - Copyright (c) 2022 Ogma Intelligent Systems Corp. https://ogma.ai

This program is published under the Attribution-NonCommercial-ShareAlike 4.0 
International (CC BY-NC-SA 4.0) License, in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

You should have received a copy of the CC BY-NC-SA 4.0 along with this 
program.  If not, see https://creativecommons.org/licenses/by-nc-sa/4.0/

Please contact licenses@ogmacorp.com regarding uses not covered by this license.
